from distutils.core import setup
setup(
  name = 'playmusic',
  packages = ['playmusic'], # this must be the same as the name above
  version = '0.4',
  description = 'Play Music',
  author = 'Sandla Honerla',
  author_email = 'sandhoners123@gmail.com',
  url = 'https://github.com/sandhoners123/playmusic', # use the URL to the github repo
  download_url = 'https://github.com/sandhoners/playmusic/archive/0.4.tar.gz', # I'll explain this in a second
  keywords = ['testing', 'logging', 'example'], # arbitrary keywords
  classifiers = [],
)
